@@ -1,4 +1,4 @@
-from src.web3client.Web3Client import Web3Client
+from web3client.Web3Client import Web3Client
 
 
 def test_get_nonce(web3client: Web3Client) -> None:
